PROGRAM check_namelist_files

!------------------------------------------------------------------------------!
! Current revisions:
! -----------------
!
!
! Former revisions:
! -----------------
! $Id: check_namelist_files.f90 846 2012-03-07 10:26:21Z maronga $
!
! 845 2012-03-07 10:23:05Z maronga
! Added call to init_cloud_physics
!
! 807 2012-01-25 11:53:51Z maronga
! Initial revision
!
! Description:
! ------------
! Perform namelist file check. The program is independent from PALM and used by 
! the shell script "mrun" to check the parameter files (e.g. p3d, p3df...) b
! efore the job is submitted/started. Source code from the PALM model in used in 
! check_namelist_files by means of the cpp directive "__check". The compiled
! program resides in the SCRIPTS folder as check_namelist_files.x.
!------------------------------------------------------------------------------!


    USE pegrid
    USE control_parameters

    IMPLICIT NONE


!
!-- Read number of processors and variable check_restart, which gives 
!-- information whether the p3d or the pd3f file shall be checked
    READ (*,*,ERR=10,END=10)  numprocs, check_restart
10  CONTINUE


!
!-- Read control parameters from NAMELIST files and read environment-variables1
    CALL parin

!
!-- Determine processor topology and local array indices
    CALL init_pegrid

!
!-- Generate grid parameters
    CALL init_grid

!
!-- Check control parameters and deduce further quantities    
    CALL check_parameters

!
!-- Check absolute temperature and pressure. Delete this call in case that
!-- init_3d_model is compiled for the parameter file check
    CALL init_cloud_physics

 END PROGRAM check_namelist_files
